@@ -1,16 +1,22 @@
 from typing import Optional
 
-from pydantic import BaseModel, RootModel, Field
+from pydantic import BaseModel, Field, RootModel
 
-from .utils import MedallionTypes, LocationLevel
-from .connection import DBConnectionMeta, S3ConnectionMeta, ClusterConnectionMeta
+from .connection import (
+    ClusterConnectionMeta,
+    DBConnectionMeta,
+    S3ConnectionMeta,
+)
+from .utils import LocationLevel, MedallionTypes
 
 
 class SchemaMeta(BaseModel):
     field_name: str
     field_type: str
     field_alias: Optional[str] = Field(None, description="Alias name field")
-    field_alias_type: Optional[str] = Field(None, description="Alias type field")
+    field_alias_type: Optional[str] = Field(
+        None, description="Alias type field"
+    )
     field_required: Optional[bool] = Field(False, description="Required field")
     field_hide: Optional[bool] = Field(False, description="Hide field")
 
@@ -43,8 +49,12 @@ class SimplifieMetadata(BaseModel):
     id: str = Field(..., description="Identifier for the metadata")
 
     # ? basic
-    title: str = Field(..., description="Title, name, or label for the metadata")
-    source: str = Field(..., description="Source of the metadata, e.g. www.example.com")
+    title: str = Field(
+        ..., description="Title, name, or label for the metadata"
+    )
+    source: str = Field(
+        ..., description="Source of the metadata, e.g. www.example.com"
+    )
     country: str = Field(..., description="Country of origin")
     year: str | int = Field(..., description="Year of the metadata")
     range_data: str = Field(..., description="Range of data, eg. 2021-2022")
@@ -55,7 +65,9 @@ class SimplifieMetadata(BaseModel):
     sub_category: Optional[str] = Field(None)
 
     # ? Schemas
-    schemas: Schemas = Field(..., description="Description of all fields in data")
+    schemas: Schemas = Field(
+        ..., description="Description of all fields in data"
+    )
 
     # ? Database
     database_access: DBConnectionMeta | ClusterConnectionMeta
@@ -71,7 +83,9 @@ class FullMetadata(SimplifieMetadata):
     source_desc: Optional[str] = Field(
         None, description="Description from the source of data"
     )
-    source_link: Optional[str] = Field(None, description="Link to the source of data")
+    source_link: Optional[str] = Field(
+        None, description="Link to the source of data"
+    )
 
     # ? Medalion & Inheritance data
     # * Use case: silver, gold
@@ -91,6 +105,12 @@ class FullMetadata(SimplifieMetadata):
     lake_access: Optional[
         S3ConnectionMeta | DBConnectionMeta | ClusterConnectionMeta
     ] = Field(None, description="Data lake access")
-    lake_meta_path: Optional[str] = Field(None, description="Data lake metadata path")
-    lake_data_path: Optional[str] = Field(None, description="Data lake data path")
-    lake_data_format: Optional[str] = Field(None, description="Data lake data format")
+    lake_meta_path: Optional[str] = Field(
+        None, description="Data lake metadata path"
+    )
+    lake_data_path: Optional[str] = Field(
+        None, description="Data lake data path"
+    )
+    lake_data_format: Optional[str] = Field(
+        None, description="Data lake data format"
+    )
