@@ -15,7 +15,6 @@ class PaginationResponseMeta(BaseResponseMeta):
 
 
 class ServiceResponse:
-
     def __init__(self, model: Any, auth: bool = False) -> None:
         self.model = model
         self.auth = auth
@@ -78,7 +77,9 @@ class ServiceResponse:
                 "description": "Success get data",
             },
             404: {
-                "model": create_model(route_name, message=(str, f"{obj} not found")),
+                "model": create_model(
+                    route_name, message=(str, f"{obj} not found")
+                ),
             },
             **self.basic(route_name),
             **kwargs,
@@ -131,7 +132,9 @@ class ServiceResponse:
                 ),
             },
             404: {
-                "model": create_model(route_name, message=(str, f"{obj} not found")),
+                "model": create_model(
+                    route_name, message=(str, f"{obj} not found")
+                ),
             },
             **self.basic(route_name),
             **kwargs,
