@@ -1,4 +1,5 @@
 from enum import Enum
+
 from deprecated import deprecated
 
 
@@ -44,7 +45,9 @@ class EnumDetails(Enum):
         return self._description_
 
 
-@deprecated(version="0.2.0", reason="EnumV2 is deprecated, use EnumDetails instead")
+@deprecated(
+    version="0.2.0", reason="EnumV2 is deprecated, use EnumDetails instead"
+)
 class EnumV2(Enum):
     @classmethod
     def list(cls):
